@@ -4,17 +4,7 @@ abstract_ocr.extract_pdf_text
 Smart PDF text extractor with OCR fallback, per-page .txt files,
 and unified manifest JSON.
 """
-from abstract_utilities import *
-import fitz  # PyMuPDF
-from pdf2image import convert_from_path
-from PIL import Image
-import pytesseract, cv2, os, tempfile, json
-from pathlib import Path
-from typing import Dict, List
-import hashlib
-
-DEFAULT_LICENSE = "CC BY-SA 4.0"
-DEFAULT_ATTRIBUTION = "Created by thedailydialectics for educational purposes"
+from .imports import *
 
 
 def preprocess_for_ocr(image_path: str) -> Image.Image:
@@ -55,18 +45,18 @@ def extract_pdf_pages(
     Extracts text and image per page, saves .txt and .png, and
     compiles a single manifest JSON for all pages.
     """
+    pdf_path = str(pdf_path)
     dir_path = os.path.dirname(pdf_path)
     rel_path=dir_path.split('/mnt/24T/media/thedailydialectics/pdfs')[1]
-    pdf_path = Path(pdf_path)
+
     pdf_name = pdf_path.stem
     subpath = f"pdfs/{rel_path}"
     pdf_url = f"{domain}/{subpath}/{pdf_name}/{pdf_name}.pdf"
-
-    output_dir = Path(output_dir)
-    text_dir = output_dir / "text"
-    img_dir = output_dir / "thumbnails"
-    text_dir.mkdir(parents=True, exist_ok=True)
-    img_dir.mkdir(parents=True, exist_ok=True)
+    os.makedirs(output_dir,exist_ok=True)
+    text_dir = os.path.join(output_dir,"text")
+    img_dir = os.path.join(output_dir,"thumbnails")
+    os.makedirs(text_dir,exist_ok=True)
+    os.makedirs(img_dir,exist_ok=True)
     
     doc = fitz.open(pdf_path)
     manifest = []
@@ -75,11 +65,12 @@ def extract_pdf_pages(
         page_num_str = str(i).zfill(3)
         filename = f"{pdf_name}_page_{page_num_str}"
         
-        img_path = img_dir / f"{filename}.png"
-        txt_path = text_dir / f"{filename}.txt"
-
+        img_path = os.path.join(img_dir ,f"{filename}.png")
+        txt_path = os.path.join(text_dir,f"{filename}.txt")
+        text = ""
         # --- Extract text
-        text = page.get_text("text").strip()
+        if os.path.isfile(txt_path):
+            text = read_from_file(txt_path).strip()
         if not text:
             # OCR fallback
             with tempfile.TemporaryDirectory() as tmpdir:
