@@ -1,7 +1,7 @@
 ## Summary Comparison and Judging Module (/src/abstract_summary_judge.py)
 """Compare new and existing text or summaries using DeepZero’s scoring ability."""
 
-from ..imports import *
+from .imports import *
 
 class SummaryJudge(metaclass=SingletonMeta):
     """
